==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_fields/FLEETBILLINGRATEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour FLEETBILLINGRATEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="FLEETBILLINGRATEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FLEETBILLINGID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTDATE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FLEETBILLINGRATEID_Type", propOrder = {
    "fleetbillingid",
    "organizationid",
    "startdate"
})
public class FLEETBILLINGRATEID_Type {

    @XmlElement(name = "FLEETBILLINGID", required = true)
    protected FLEETBILLINGID_Type fleetbillingid;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "STARTDATE", required = true)
    protected DATETIME startdate;

    /**
     * Obtient la valeur de la propriété fleetbillingid.
     * 
     * @return
     *     possible object is
     *     {@link FLEETBILLINGID_Type }
     *     
     */
    public FLEETBILLINGID_Type getFLEETBILLINGID() {
        return fleetbillingid;
    }

    /**
     * Définit la valeur de la propriété fleetbillingid.
     * 
     * @param value
     *     allowed object is
     *     {@link FLEETBILLINGID_Type }
     *     
     */
    public void setFLEETBILLINGID(FLEETBILLINGID_Type value) {
        this.fleetbillingid = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété startdate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTARTDATE() {
        return startdate;
    }

    /**
     * Définit la valeur de la propriété startdate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTARTDATE(DATETIME value) {
        this.startdate = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/FLEETBILLINGRATEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for FLEETBILLINGRATEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="FLEETBILLINGRATEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FLEETBILLINGID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTDATE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FLEETBILLINGRATEID_Type", propOrder = {
    "fleetbillingid",
    "organizationid",
    "startdate"
})
public class FLEETBILLINGRATEID_Type {

    @XmlElement(name = "FLEETBILLINGID", required = true)
    protected FLEETBILLINGID_Type fleetbillingid;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "STARTDATE", required = true)
    protected DATETIME startdate;

    /**
     * Gets the value of the fleetbillingid property.
     * 
     * @return
     *     possible object is
     *     {@link FLEETBILLINGID_Type }
     *     
     */
    public FLEETBILLINGID_Type getFLEETBILLINGID() {
        return fleetbillingid;
    }

    /**
     * Sets the value of the fleetbillingid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FLEETBILLINGID_Type }
     *     
     */
    public void setFLEETBILLINGID(FLEETBILLINGID_Type value) {
        this.fleetbillingid = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the startdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTARTDATE() {
        return startdate;
    }

    /**
     * Sets the value of the startdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTARTDATE(DATETIME value) {
        this.startdate = value;
    }

}
